# -*- coding: utf-8 -*-
"""
Created on Mon Nov  4 13:54:06 2024

@author: AleksanderHykkerud
"""
# API reference https://www.beijerelectronics.com/docs/iX-251-Reference/en/web-server.html

import requests
import json

def get_tags(url,session):
    result = session.get("http://"+url+"/tags")
    if result.status_code == 200:
        return result.json()
    else:
        return False

def get_value(url,tag,session):
    
    headers = {'Content-type': "application/json",
               "Accept": "application/json"}
    result = session.get("http://"+url+"/tags/"+tag,headers=headers)

    if result.status_code == 200:
        return result
    else:
        return False

def get_values(url,tags,session,process_values = True):
    url = "http://"+url+"/tagbatch"
    data = {
    "getTags": tags,  # List of tag names to return

    }
    headers = {'Content-type': "application/json",
               "Accept": "application/json"}
    response = session.post(url, json=data,headers=headers)
    
    if response.status_code == 200:
        if process_values:
            values = {}
            for item in response.json()["tags"]:
                values[item["name"]] = item["value"]
            return values
        return response
    else:
        return response






from setuptools import setup, find_packages

setup(
    name="ix_rest_tools",
    version="0.1.0",
    description="Python library for interacting with Beijer Electronics iX Web Server API.",
    long_description="Python wrapper for Beijer Electronics iX Web Server API",
    long_description_content_type="text/plain",
    url="https://github.com/Doscon-prime/ix_rest_tools",
    author="Your Name",
    author_email="aleksander@doscon.no",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        "requests",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)